@@ -328,6 +328,7 @@ volume_is_blank (GVolume *volume)
         is_blank = FALSE;
 
         udi = g_volume_get_identifier (volume, G_VOLUME_IDENTIFIER_KIND_HAL_UDI);
+        DEBUG_PRINT ("Got udi: %s\n", udi);
         if (udi != NULL) {
                 is_blank = libhal_device_get_property_bool (ctx,
                                                             udi,
@@ -336,6 +337,7 @@ volume_is_blank (GVolume *volume)
         }
         g_free (udi);
 
+        DEBUG_PRINT ("is-blank: %d\n", is_blank);
         return is_blank;
 }
 
@@ -374,19 +376,24 @@ drive_is_cd_device (GDrive *drive)
         is_cd = FALSE;
 
         udi = g_drive_get_identifier (drive, G_VOLUME_IDENTIFIER_KIND_HAL_UDI);
+        DEBUG_PRINT ("Got udi: %s\n", udi);
+
         if (udi != NULL) {
                 char *drive_type;
                 drive_type = libhal_device_get_property_string (ctx,
                                                                 udi,
                                                                 "storage.drive_type",
                                                                 NULL);
-                if (drive_type != NULL && strcmp (drive_type, "cdrom")) {
+                DEBUG_PRINT ("Got drive type: '%s'\n", drive_type);
+                if (drive_type != NULL && strcmp (drive_type, "cdrom") == 0) {
                         is_cd = TRUE;
                 }
                 g_free (drive_type);
         }
         g_free (udi);
 
+        DEBUG_PRINT ("is-cdrom: %d\n", is_cd);
+
         return is_cd;
 }
 
@@ -399,7 +406,6 @@ nautilus_burn_get_file_items (NautilusMenuProvider *provider,
         NautilusMenuItem *item;
         NautilusFileInfo *file_info;
         GFile            *file;
-        GFileInfo        *info;
         GMount           *mount;
         GVolume          *volume;
         GDrive           *drive;
@@ -408,6 +414,8 @@ nautilus_burn_get_file_items (NautilusMenuProvider *provider,
         gboolean          is_iso;
         gboolean          is_cue;
 
+        DEBUG_PRINT ("Getting file items\n");
+
         if (!selection || selection->next != NULL) {
                 return NULL;
         }
@@ -421,24 +429,15 @@ nautilus_burn_get_file_items (NautilusMenuProvider *provider,
         file = nautilus_file_info_get_location (file_info);
 
         if (file == NULL) {
-                return NULL;
-        }
+                DEBUG_PRINT ("No file found\n");
 
-        info = g_file_query_info (file,
-                                  G_FILE_ATTRIBUTE_STANDARD_TYPE ","
-                                  G_FILE_ATTRIBUTE_MOUNTABLE_UNIX_DEVICE ","
-                                  G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE ","
-                                  G_FILE_ATTRIBUTE_MOUNTABLE_HAL_UDI,
-                                  0,
-                                  NULL,
-                                  NULL);
-        if (info == NULL) {
                 return NULL;
         }
 
         is_local = TRUE;
 
         mime_type = nautilus_file_info_get_mime_type (file_info);
+        DEBUG_PRINT ("Mime type: %s\n", mime_type);
         if (! mime_type) {
                 return NULL;
         }
@@ -482,12 +481,14 @@ nautilus_burn_get_file_items (NautilusMenuProvider *provider,
         drive = NULL;
         volume = NULL;
 
-        mount = g_file_find_enclosing_mount (file, NULL, NULL);
+        mount = nautilus_file_info_get_mount (file_info);
         if (mount != NULL) {
                 drive = g_mount_get_drive (mount);
                 volume = g_mount_get_volume (mount);
         } else {
-                g_debug ("Mount not found");
+                char *uri = g_file_get_uri (file);
+                DEBUG_PRINT ("Mount not found: %s\n", uri);
+                g_free (uri);
         }
 
         if (drive == NULL && volume != NULL) {
@@ -496,6 +497,9 @@ nautilus_burn_get_file_items (NautilusMenuProvider *provider,
         } else if (volume == NULL && drive != NULL) {
                 /* case B */
                 volume = drive_get_first_volume (drive);
+                if (volume == NULL) {
+                        DEBUG_PRINT ("Volume not found\n");
+                }
         }
 
         if (drive != NULL
@@ -544,7 +548,7 @@ nautilus_burn_get_background_items (NautilusMenuProvider *provider,
 
         scheme = nautilus_file_info_get_uri_scheme (current_folder);
 
-        if (!strcmp (scheme, "burn")) {
+        if (strcmp (scheme, "burn") == 0) {
                 NautilusMenuItem *item;
 
                 item = nautilus_menu_item_new ("NautilusBurn::write_menu",
@@ -740,7 +744,7 @@ burn_monitor_cb (GFileMonitor     *monitor,
                  GFileMonitorEvent event_type,
                  NautilusBurn     *burn)
 {
-        DEBUG_PRINT ("Monitor callback type %d: %s: %s\n", event_type, text_uri, info_uri);
+        DEBUG_PRINT ("Monitor callback type %d\n", event_type);
 
         /* only queue the action if it has a chance of changing the state */
         if (event_type == G_FILE_MONITOR_EVENT_CREATED) {
